@@ -48,6 +48,8 @@
 #include "scripts/translator.h"
 
 #include "parleyactions.h"
+#include "parleyadaptor.h"
+
 #include <KActionCollection>
 #include <KToggleAction>
 #include <KActionMenu>
@@ -55,10 +57,10 @@
 
 #include <QtCore/QTimer>
 #include <QtCore/QSignalMapper>
-#include <QtGui/QDockWidget>
-#include <QtGui/QHeaderView>
-#include <QtGui/QMenu>
-#include <QtGui/QStackedWidget>
+#include <QtWidgets/QDockWidget>
+#include <QtWidgets/QHeaderView>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QStackedWidget>
 #include <QScrollArea>
 
 using namespace Editor;
@@ -138,7 +140,7 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
 
     m_spellCheckMenu->menu()->clear();
     for (int i = 0; i < doc->identifierCount(); ++i) {
-        KAction* languageSpellCheck = new KAction(doc->identifier(i).name(), m_spellCheckMenu->menu());
+        QAction* languageSpellCheck = new QAction(doc->identifier(i).name(), m_spellCheckMenu->menu());
         m_spellCheckMenu->menu()->addAction(languageSpellCheck);
         m_spellCheckMapper->setMapping(languageSpellCheck, i);
         connect(languageSpellCheck, SIGNAL(triggered()), m_spellCheckMapper, SLOT(map()));
@@ -149,13 +151,13 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
 void EditorWindow::initDockWidgets()
 {
     // Lesson dockwidget
-    QDockWidget *lessonDockWidget = new QDockWidget(i18n("Lessons"), this);
+    QDockWidget *lessonDockWidget = new QDockWidget(i18n("Units"), this);
     lessonDockWidget->setObjectName("LessonDock");
     m_lessonView = new LessonView(this);
     lessonDockWidget->setWidget(m_lessonView);
     addDockWidget(Qt::LeftDockWidgetArea, lessonDockWidget);
     m_dockWidgets.append(lessonDockWidget);
-    actionCollection()->addAction("show_lesson_dock", lessonDockWidget->toggleViewAction());
+    actionCollection()->addAction("show_units_dock", lessonDockWidget->toggleViewAction());
 
     m_lessonModel = new LessonModel(this);
     m_lessonView->setModel(m_lessonModel);
@@ -410,6 +412,18 @@ void EditorWindow::initActions()
     ParleyActions::create(ParleyActions::ShowScriptManager, this, SLOT(slotShowScriptManager()), actionCollection());
     ParleyActions::create(ParleyActions::LanguagesProperties, m_mainWindow->parleyDocument(), SLOT(languageProperties()), actionCollection());
     ParleyActions::createUploadAction(m_mainWindow->parleyDocument(), SLOT(uploadFile()), actionCollection());
+
+    new EditorWindowAdaptor(this);
+
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    dbus.registerObject("/AddWithTranslation", this);
+}
+
+void EditorWindow::addWordWithTranslation(const QStringList &w)
+{
+    KEduVocExpression *kexpr = new KEduVocExpression(w);
+
+    m_vocabularyModel->appendEntry(kexpr);
 }
 
 void EditorWindow::initModel()
@@ -417,7 +431,7 @@ void EditorWindow::initModel()
     m_vocabularyModel = new VocabularyModel(this);
     m_vocabularyFilter = new VocabularyFilter(this);
     m_vocabularyFilter->setSourceModel(m_vocabularyModel);
-    m_vocabularyView->setFilter(m_vocabularyFilter);
+    m_vocabularyView->setModel(m_vocabularyFilter);
 
 //    connect(m_mainWindow->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), m_vocabularyModel, SLOT(setDocument(KEduVocDocument*)));
 //    connect(m_mainWindow->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), m_vocabularyView, SLOT(setDocument(KEduVocDocument*)));
@@ -432,16 +446,13 @@ void EditorWindow::initView()
     QWidget *mainWidget = new QWidget(this);
     setCentralWidget(mainWidget);
     QVBoxLayout *topLayout = new QVBoxLayout(mainWidget);
-    topLayout->setMargin(KDialog::marginHint());
-    topLayout->setSpacing(KDialog::spacingHint());
 
-    m_searchLine = new KLineEdit(this);
+    m_searchLine = new QLineEdit(this);
     m_searchLine->show();
     m_searchLine->setFocusPolicy(Qt::ClickFocus);
-    m_searchLine->setClearButtonShown(true);
-    m_searchLine->setClickMessage(i18n("Enter search terms here"));
-
-//     m_searchLine->setToolTip(i18n("Search your vocabuary"));
+    m_searchLine->setClearButtonEnabled(true);
+    m_searchLine->setPlaceholderText(i18n("Enter search terms here"));
+    m_searchLine->setToolTip(i18n("Search your vocabulary"));
 
     QLabel *label = new QLabel(i18n("S&earch:"), this);
     label->setBuddy(m_searchLine);
@@ -449,14 +460,12 @@ void EditorWindow::initView()
 
     m_searchWidget = new QWidget(this);
     QHBoxLayout* layout = new QHBoxLayout(m_searchWidget);
-    layout->setSpacing(KDialog::spacingHint());
     layout->setMargin(0);
     layout->addWidget(label);
     layout->addWidget(m_searchLine);
 
 ///@todo     centralWidget()-> delete layout
     QVBoxLayout * rightLayout = new QVBoxLayout();
-    rightLayout->setSpacing(KDialog::spacingHint());
     rightLayout->setMargin(0);
     rightLayout->addWidget(m_searchWidget);
     m_searchWidget->setVisible(Prefs::showSearch());
@@ -514,5 +523,3 @@ void EditorWindow::slotLanguagesChanged()
 {
     m_vocabularyModel->resetLanguages();
 }
-
-#include "editor.moc"
