@@ -25,8 +25,8 @@
 
 // KDE
 class KActionMenu;
-class KAction;
-class KUrl;
+class QAction;
+class QUrl;
 
 // KEduVocDocument
 class KEduVocExpression;
@@ -52,7 +52,7 @@ public:
 
     KActionMenu* columnsActionMenu();
 
-    void setFilter(VocabularyFilter * model);
+    void setModel(VocabularyFilter * model);
 
     /** Save column visibility settings */
     void saveColumnVisibility() const;
@@ -107,19 +107,18 @@ private:
     void selectIndex(const QModelIndex &index);
     // trap enter presses at the end of the document to add a new entry instead of moving to the first cell
     bool eventFilter(QObject *obj, QEvent *event);
-
-    // Make this private to avoid inadvertent use. Instead use setFilter() which is public.
+#if 0
     virtual void setModel(QAbstractItemModel *model) {
         Q_UNUSED(model)
     }
-
-    KAction* m_appendEntryAction;
-    KAction* m_deleteEntriesAction;
-    KAction* m_copyAction;
-    KAction* m_cutAction;
-    KAction* m_pasteAction;
-    KAction* m_selectAllAction;
-    KAction* m_clearSelectionAction;
+#endif
+    QAction* m_appendEntryAction;
+    QAction* m_deleteEntriesAction;
+    QAction* m_copyAction;
+    QAction* m_cutAction;
+    QAction* m_pasteAction;
+    QAction* m_selectAllAction;
+    QAction* m_clearSelectionAction;
 
     VocabularyFilter* m_model;
     VocabularyDelegate* m_vocabularyDelegate;
