@@ -16,7 +16,7 @@
 #define CONJUGATIONBACKENDMODE_H
 
 #include "abstractbackendmode.h"
-#include "practice/testentrymanager.h"
+#include "practice/sessionmanagerbase.h"
 
 namespace Practice
 {
@@ -26,13 +26,15 @@ class ConjugationBackendMode : public AbstractBackendMode
     Q_OBJECT
 
 public:
-    ConjugationBackendMode(const PracticeOptions& PracticeOptions, AbstractFrontend *frontend,
-                           QObject *parent, Practice::TestEntryManager* testEntryManager, KEduVocDocument* doc);
+    ConjugationBackendMode(AbstractFrontend *frontend,
+                           QObject *parent, Practice::SessionManagerBase* sessionManager, KEduVocDocument* doc);
 
     virtual bool setTestEntry(TestEntry* current);
 
+    /** Return the worst pregrade for any pronoun of the current entry */
+    virtual grade_t currentPreGradeForEntry() const;
     /** Return the worst grade for any pronoun of the current entry */
-    virtual grade_t currentGradeForEntry();
+    virtual grade_t currentGradeForEntry() const;
 
     virtual void updateGrades();
 
@@ -43,7 +45,7 @@ public Q_SLOTS:
 private:
     QStringList validPersonalPronouns();
 
-    TestEntryManager* m_testEntryManager;
+    SessionManagerBase* m_sessionManager;
     KEduVocDocument* m_doc;
 
     QString m_currentTense;
