@@ -16,7 +16,7 @@
 #define GENDERBACKENDMODE_H
 
 #include "multiplechoicebackendmode.h"
-#include "practice/testentrymanager.h"
+#include "practice/sessionmanagerbase.h"
 
 namespace Practice
 {
@@ -26,13 +26,20 @@ class GenderBackendMode : public MultipleChoiceBackendMode
     Q_OBJECT
 
 public:
-    GenderBackendMode(const PracticeOptions& PracticeOptions, AbstractFrontend *frontend, QObject *parent, Practice::TestEntryManager* testEntryManager, KEduVocDocument* doc);
+    GenderBackendMode(AbstractFrontend *frontend,
+                      QObject *parent, Practice::SessionManagerBase* sessionManager,
+                      KEduVocDocument* doc);
+
+    /** Start practicing a new word */
+    virtual bool setTestEntry(TestEntry* current);
 
 protected:
     virtual void prepareChoices(TestEntry* current);
     virtual void updateGrades();
 
 private:
+    /** Reference to the kvocdoc */
+    const KEduVocDocument & m_doc;
     KEduVocArticle m_articles;
     QString m_masculine;
     QString m_feminine;
